# Managed Code
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/managed-code#overview)
  * [Features with Code Support](https://help.sap.com/docs/leanix/ea/managed-code#features-with-code-support)
  * [Viewing Code Configurations](https://help.sap.com/docs/leanix/ea/managed-code#viewing-code-configurations)
  * [Viewing Execution Details](https://help.sap.com/docs/leanix/ea/managed-code#viewing-execution-details)
  * [Updating Code](https://help.sap.com/docs/leanix/ea/managed-code#updating-code)
  * [Troubleshooting](https://help.sap.com/docs/leanix/ea/managed-code#troubleshooting)
  * [Related Information](https://help.sap.com/docs/leanix/ea/managed-code#related-information)


View and manage all custom code configurations used in automations, calculations, and webhooks across your workspace. Monitor execution logs to track history, troubleshoot issues, and ensure your code runs as expected.
